::: beignet.add_legendre_polynomial
::: beignet.differentiate_legendre_polynomial
::: beignet.divide_legendre_polynomial
::: beignet.evaluate_legendre_polynomial
::: beignet.evaluate_legendre_polynomial_2d
::: beignet.evaluate_legendre_polynomial_3d
::: beignet.evaluate_legendre_polynomial_cartesian_2d
::: beignet.evaluate_legendre_polynomial_cartesian_3d
::: beignet.fit_legendre_polynomial
::: beignet.integrate_legendre_polynomial
::: beignet.legendre_polynomial_companion
::: beignet.legendre_polynomial_domain
::: beignet.legendre_polynomial_from_roots
::: beignet.legendre_polynomial_one
::: beignet.legendre_polynomial_power
::: beignet.legendre_polynomial_roots
::: beignet.legendre_polynomial_to_polynomial
::: beignet.legendre_polynomial_vandermonde
::: beignet.legendre_polynomial_vandermonde_2d
::: beignet.legendre_polynomial_vandermonde_3d
::: beignet.legendre_polynomial_weight
::: beignet.legendre_polynomial_x
::: beignet.legendre_polynomial_zero
::: beignet.linear_legendre_polynomial
::: beignet.multiply_legendre_polynomial
::: beignet.multiply_legendre_polynomial_by_x
::: beignet.subtract_legendre_polynomial
::: beignet.trim_legendre_polynomial_coefficients
